# coding: utf-8

import json
import os
import sys

from recycle.lib import my_print, my_input
from recycle.config import CONFIG_PATH, HOME, TRASH_PATH, ENABLE_EMOJI

zsh_config = """# py-recycle config start
# Don't put your config inside "# py-recycle config start" and "# py-recycle config end"!
# Else it will be DELETE!
compdef '_files -W {}`pwd`' undel
compdef '_files -W {}`pwd`' pdel
compdef '_files -W {}`pwd`' tt
# py-recycle config end
""".format(
    TRASH_PATH, TRASH_PATH, TRASH_PATH
)

bash_config = """# py-recycle config start
# Don't put your config inside "# py-recycle config start" and "# py-recycle config end"!
# Else it will be DELETE!
_undel() {{
    local trash_home="{}"
    local current_path=`pwd`
    local current_arg="${{COMP_WORDS[COMP_CWORD]}}"
    local trash_dir=$trash_home$current_path/${{COMP_LINE:6:999}}
    local IFS=$'\t\n'

    if [[ $current_arg =~ ^/ ]] ; then
      # /a/b/c
      return 0
    elif [[ $current_path =~ $trash_home ]] ; then
      # in {}
      return 0
    elif [[ ! -d $trash_dir ]] ; then
      # {}`pwd` don't exists
      return 0
    elif [[ -d $trash_dir ]] ; then
      COMPREPLY=( $(compgen -W "`ls -a $trash_dir|grep -Pv '^\.{{1,2}}$'`" -- ${{current_arg}}) )
      return 0
    fi
}}

complete -o filenames -o dirnames -o default -F _undel undel
complete -o filenames -o dirnames -o default -F _undel pdel
complete -o filenames -o dirnames -o default -F _undel tt
# py-recycle config end
""".format(
    TRASH_PATH, TRASH_PATH, TRASH_PATH
)

shell_config = {"zsh": zsh_config, "bash": bash_config}


def install(shell, path):
    shellrc_path = "{}/.{}rc".format(HOME, shell)

    if not os.path.exists("/bin/" + shell):
        return my_print("your don't have {}, skip it".format(shell))
    config_info = ""
    config_info_bp = ""
    if os.path.isfile(shellrc_path):
        config_info = open(shellrc_path, "r").read()
        config_info_bp = config_info
        if "# py-recycle config start" in config_info:
            config_info = config_info.split("\n")
            config_info = "\n".join(
                config_info[0: config_info.index("# py-recycle config start")]
                + config_info[config_info.index("# py-recycle config end") + 1:]
            )
    try:
        open(shellrc_path, "w").write(config_info + shell_config[shell])
        my_print("Installed in {}, enjoy it :)".format(shellrc_path))
    except:
        open(shellrc_path + ".old", "w").write(config_info_bp)
        my_print(
            "Install Failed in {}, old config file in {}.".format(
                shellrc_path, shellrc_path + ".old"
            )
        )

    if not path:
        return

    path = "export PATH={}\n".format(path)
    if path in open(shellrc_path).readlines():
        return
    my_print('Write "{}" in {}'.format(path.strip(), shellrc_path))
    open(shellrc_path, "a+").write(path)


def main():
    scripts_dir_path = os.path.dirname(sys.argv[0])
    if scripts_dir_path in os.getenv("PATH"):
        path = None
    elif (
        "n"
        in my_input(
            'Add "{}" to your PATH, to enable it?[Y/n]'.format(
                scripts_dir_path)
        ).lower()
    ):
        path = None
    else:
        path = "{}:$PATH".format(scripts_dir_path)

    install("zsh", path)
    install("bash", path)

    if not os.path.exists(TRASH_PATH):
        os.makedirs(TRASH_PATH)
    open(CONFIG_PATH, "w").write(json.dumps(
        dict(
            TRASH_PATH=TRASH_PATH,
            ENABLE_EMOJI=ENABLE_EMOJI
        ),
        indent=4
    ))
    command = "source ~/.{}rc".format(os.getenv("SHELL").split("/")[-1])
    my_print('\nPlease Execute "{}"\n'.format(command))



# coding: utf-8

import json
import os

HOME = os.path.expanduser("~")
INIT_TRASH_PATH = HOME + "/.Trash"
TRASH_DATETIME_FORMAT = "%Y-%m-%d_%H:%M:%S%f_"
TRASH_REGEX = "\d{4}-\d{2}-\d{2}_\d{2}:\d{2}:\d{8}_[0-9\.]+[A-Z]?"
CONFIG_PATH = HOME + "/.py_recycle.json"
if not os.path.isfile(CONFIG_PATH):
    open(CONFIG_PATH, "w").write("{}")
config = json.loads(open(CONFIG_PATH).read())
TRASH_PATH = config.get("TRASH_PATH") or INIT_TRASH_PATH
ENABLE_EMOJI = config.get("ENABLE_EMOJI", True)
EMOJIS = {
    "file": "📄",
    "directory": "📁"
}



# coding: utf-8

import os
import json

from recycle.config import TRASH_PATH
from recycle.lib import (
    operations,
    search_files,
    generate_trash_file_name,
    execute_move,
    directory_exists,
)


def move_to_trash(trash_dir, file_regex):
    if not directory_exists(trash_dir):
        return

    for file_name in search_files(trash_dir, file_regex):
        del_file = os.path.join(trash_dir, file_name)
        absolute_trash_file_dir = TRASH_PATH + del_file
        if not os.path.exists(absolute_trash_file_dir):
            os.makedirs(absolute_trash_file_dir)
        trash_file = os.path.join(
            absolute_trash_file_dir, generate_trash_file_name(del_file)
        )
        execute_move(del_file, trash_file)


def main():
    for parent_dir, file_regex, _ in operations():
        move_to_trash(parent_dir, file_regex)



from setuptools import setup, find_packages

setup(
    name="py-recycle",
    version="1.2.12",
    description=("Recycle for linux"),
    long_description=open("README.rst").read(),
    author="twfb",
    author_email="twfb@hotmail.com",
    maintainer="twfb",
    maintainer_email="twfb@hotmail.com",
    license="BSD License",
    packages=find_packages(),
    platforms=["all"],
    include_package_data=True,
    url="https://github.com/twfb/recycle",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: Implementation",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Software Development :: Libraries",
    ],
    entry_points={
        "console_scripts": [
            "del=recycle.move_to_trash:main",
            "undel=recycle.recover_from_trash:main",
            "tt=recycle.trash_tree:main",
            "recycle_init=recycle.init_env:main",
            "pdel=recycle.permanently_delete:main",
        ],
    },
),
